import { Component, OnInit } from '@angular/core';
import { ModalController } from '@ionic/angular';
import { Router } from '@angular/router';
import { CloudObject, CloudQuery } from 'src/lib/ncloud';

// 正确导入所有组件
import { AllProductsModalComponent } from '../all-products-modal/all-products-modal.component';
import { DetailModalComponent } from '../detail-modal/detail-modal.component';
import { SaleCardComponent } from '../component/sale-card/sale-card.component';

// 移除或正确导入 FmChatModalInput
// 如果 FmChatModalInput 是一个模块，请使用下面的导入方式（假设它是一个模块）
// import { FmChatModalInputModule } from 'fmode-ng';

// 如果 FmChatModalInput 是一个组件，请使用下面的导入方式（假设它是一个组件）
// import { FmChatModalInputComponent } from 'fmode-ng';

// 如果 FmChatModalInput 不是必需的，建议先移除以确保编译通过
// 这里假设我们移除了它

// 导入必要的模块
import { IonicModule } from '@ionic/angular';
import { CommonModule } from '@angular/common';

@Component({
  selector: 'app-tab3',
  templateUrl: 'tab3.page.html',
  styleUrls: ['tab3.page.scss'],
  standalone: true,
  imports: [
    IonicModule,
    CommonModule,
    AllProductsModalComponent,
    DetailModalComponent,
    SaleCardComponent
    // 如果 FmChatModalInput 是模块或组件，根据实际情况添加
    // FmChatModalInputModule 或 FmChatModalInputComponent
  ]
})
export class Tab3Page implements OnInit {
  showDetailModal = false;  // 控制详情模态显示与否
  currentProduct: any;      // 当前选择的药品信息

  categories = [
    { name: '皮肤用药', image: 'https://app.fmode.cn/dev/jxnu/202226701019/yao1.png' },
    { name: '肠胃消化', image: 'https://app.fmode.cn/dev/jxnu/202226701019/yao5.png' },
    { name: '呼吸用药', image: 'https://app.fmode.cn/dev/jxnu/202226701019/yao11.png' },
    { name: '营养补充', image: 'https://app.fmode.cn/dev/jxnu/202226701019/yao9.png' },
    { name: '家庭常备', image: 'https://app.fmode.cn/dev/jxnu/202226701019/yao12.png' },
    { name: '耳鼻咽喉', image: 'https://app.fmode.cn/dev/jxnu/202226701019/yao10.png' },
    { name: '骨科疼痛', image: 'https://app.fmode.cn/dev/jxnu/202226701019/yao6.png' },
    { name: '心脑血管', image: 'https://app.fmode.cn/dev/jxnu/202226701019/yao7.png' },
  ];

  products: Array<CloudObject> = [];
  allProducts: Array<CloudObject> = []; // 存储所有药品数据，用于分类过滤

  hotProducts: Array<CloudObject> = [];
  specialProducts: Array<CloudObject> = [];

  constructor(
    private modalCtrl: ModalController,
    private router: Router,
  ) {}

  /**
   * 初始化生命周期钩子，加载药品数据
   */
  async ngOnInit() {
    await this.loadProducts();
  }

  /**
   * 加载药品数据并进行分类
   */
  async loadProducts() {
    try {
      const query = new CloudQuery('Drug');
      this.products = await query.find();
      this.allProducts = [...this.products]; // 初始化所有产品

      // 分类“热销”和“特价”药品
      this.hotProducts = this.allProducts.filter(product => product.get('marketing') === 'hot');
      this.specialProducts = this.allProducts.filter(product => product.get('marketing') === 'special');
    } catch (error) {
      console.error('加载药品数据失败', error);
    }
  }

  /**
   * 打开详情模态窗口
   * @param product 当前选择的药品
   */
  openDetailModal(product: any) {
    this.currentProduct = product;
    this.showDetailModal = true;
  }

  /**
   * 关闭详情模态窗口
   */
  closeDetailModal() {
    this.showDetailModal = false;
    this.currentProduct = null;
  }

  /**
   * 根据分类导航到 drug-category 页面
   * @param category 选择的分类
   */
  onCategoryClick(category: any) {
    this.router.navigate(['/drug-category', category.name]);
  }

  // 搜索功能相关属性
  searchTerm: string = '';

  /**
   * 搜索功能，根据输入关键字过滤药品
   * @param event 输入事件
   */
  async searchProducts(event: any) {
    this.searchTerm = event.detail.value.toLowerCase();
    if (this.searchTerm) {
      this.products = this.allProducts.filter(product =>
        product.get('name').toLowerCase().includes(this.searchTerm) ||
        product.get('function').toLowerCase().includes(this.searchTerm) ||
        product.get('composition').toLowerCase().includes(this.searchTerm)
      );
    } else {
      this.products = [...this.allProducts];
    }
  }

  /**
   * 查看更多功能，打开 AllProductsModalComponent 模态窗口
   * @param type 类型（热销或特价）
   */
  async viewMore(type: string) {
    let filteredProducts: Array<CloudObject> = [];
    let title: string = '';

    if (type === 'hot') {
      filteredProducts = this.hotProducts;
      title = '热销药品';
    } else if (type === 'special') {
      filteredProducts = this.specialProducts;
      title = '特价药品';
    }

    const modal = await this.modalCtrl.create({
      component: AllProductsModalComponent,
      componentProps: {
        products: filteredProducts,
        title: title
      },
      cssClass: 'bottom-modal'
    });

    return await modal.present();
  }
}